Clazz.declarePackage("J.api");
Clazz.load(["J.api.FontManager"], "J.api.GenericPlatform", null, function(){
var c$ = Clazz.declareInterface(J.api, "GenericPlatform", J.api.FontManager);
});
;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
